//
// tardy - a tar post-processor
// Copyright (C) 2011, 2012 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <libtardy/rcstring/list.h>


rcstring_list
rcstring_list::quote_c(void)
    const
{
    rcstring_list result;
    for
    (
        contents_t::const_iterator it = contents.begin();
        it != contents.end();
        ++it
    )
    {
        result.push_back(it->quote_c());
    }
    return result;
}


// vim: set ts=8 sw=4 et :
